import React, { useState } from 'react';
import { BrowserRouter, Route, IndexRoute, Switch, withRouter } from 'react-router-dom';

import { createMuiTheme, MuiThemeProvider } from '@material-ui/core/styles';

import { CircularProgress } from '@material-ui/core';

import SettingsPage from 'pages/settings';
import ProjectsPage from 'pages/projects';
import WelcomePage from 'pages/welcome';
import Layout from 'components/layout';

import injectSettings from 'lib/settings';


/* *** routes - main app *** */
const App = injectSettings((props) => {
    const settings = props.settings;
    if (settings && settings.fetching) {
        return <CircularProgress size={ 60 } />
    }

    return (
        <BrowserRouter>
            <Route path="/" render={ (props) => (
                <Layout {...props}>
                    <Switch>
                        <Route path="/settings" exact component={ SettingsPage } />
                        <Route path="/projects" exact component={ ProjectsPage } />
                        <Route path="*" component={ WelcomePage } />
                    </Switch>
                </Layout>
            ) }/>        
        </BrowserRouter>
    );

});

/* *** main theme *** */
const theme = createMuiTheme({
    palette: {
        primary: {
            main: '#17b7ff'
        },
        background: {
            paper: '#FFFFFF',
            default: '#FAFAFA'
        },
        type: 'light',
        contrastThreshold: 2
    },
    shape: {
        borderRadius: 0
    }
});

export default () => (
    <MuiThemeProvider theme={ theme }>
        <App />
    </MuiThemeProvider>
);
