import React, { useContext } from 'react';

import { makeStyles } from '@material-ui/core/styles';
import { Container, Box, Paper, Button, TextField } from '@material-ui/core';

import { Formik } from 'formik';
import { SettingsContext } from 'lib/settings';



const useStyles = makeStyles(theme => ({
    root: {
        width: '100%',
        maxWidth: 360,
        backgroundColor: theme.palette.background.paper,
    },
    inline: {
        display: 'inline',
    },
    button: {
        margin: theme.spacing(1),
    },

    textField: {
        marginLeft: theme.spacing(1),
        marginRight: theme.spacing(1),
        
    },

}));


export default (props) => {
    const classes = useStyles();
    const settings = useContext(SettingsContext);

    console.info(settings);

    return (
        <Formik
            initialValues={{ username: settings.username || "", password: settings.password || "" }}
            validate={ values => {
                let errors = {};
                if (!values.username) {
                    errors.username = 'Required';
                }
                if (!values.password) {
                    errors.password = 'Required';
                }
                return errors;
            }}
            onSubmit={ async (values, { setSubmitting }) => {
                setSubmitting(true);
                try {
                    await settings.save(values);
                } catch (err) {
                    //TODO
                }
                setSubmitting(false);
            }}
            >

      {({
        values,
        errors,
        touched,
        handleChange,
        handleBlur,
        handleSubmit,
        isSubmitting,
      }) => (

        <Container maxWidth="md">
            <Box m={ 2 }>
                <Paper>
                    <form onSubmit={ handleSubmit }>
                        <TextField
                            label="Username"
                            className={ classes.textField }
                            name="username"
                            value={ values.username }
                            onChange={ handleChange }
                            margin="normal"
                            disabled={ isSubmitting }
                            
                            helperText={ errors.username }
                            error={ !!errors.username }
                            />
                        <TextField
                            label="Password"
                            className={ classes.textField }
                            name="password"
                            value={ values.password }
                            onChange={ handleChange }
                            margin="normal"
                            disabled={ isSubmitting }
                            
                            helperText={ errors.email && touched.email && errors.email }
                            />

                        <Button className={ classes.button } disabled={ isSubmitting }>
                            Cancel
                        </Button>
                        <Button type="submit" variant="contained" color="primary" className={classes.button} disabled={ isSubmitting }>
                            Ok
                        </Button>
                    </form>
                </Paper>
            </Box>
        </Container>
        ) }
      </Formik>
    );
}